[PATCH] gnu: pocl: Update to 3.1

  • Done
  • quality assurance status badge
Details
2 participants
  • Andy Tai
  • Ludovic Courtès
Owner
unassigned
Submitted by
Andy Tai
Severity
normal

Debbugs page

Andy Tai wrote 2 years ago
(address . guix-patches@gnu.org)(name . Andy Tai)(address . atai@atai.org)
20230309090624.765-1-atai@atai.org
* gnu/packages/opencl.scm (pocl): Update to 3.1
[native-inputs]: Add python-3
[arguments]: Update RPATH
---
gnu/packages/opencl.scm | 62 ++++++++++++++++++++++-------------------
1 file changed, 33 insertions(+), 29 deletions(-)

Toggle diff (80 lines)
--
2.39.1
Andy Tai wrote 2 years ago
[PATCH v2] gnu: pocl: Update to 3.1
(address . 62070@debbugs.gnu.org)(name . Andy Tai)(address . atai@atai.org)
20230312090727.8588-1-atai@atai.org
* gnu/packages/opencl.scm (pocl): Update to 3.1
[native-inputs]: Add python-3
[arguments]: Update RPATH. Handle failed tests on aarch64
---
gnu/packages/opencl.scm | 68 +++++++++++++++++++++++------------------
1 file changed, 39 insertions(+), 29 deletions(-)

Toggle diff (86 lines)
diff --git a/gnu/packages/opencl.scm b/gnu/packages/opencl.scm
index 2e506156b2..990f84ff25 100644
--- a/gnu/packages/opencl.scm
+++ b/gnu/packages/opencl.scm
@@ -279,38 +279,48 @@ (define-public beignet
(define-public pocl
(package
(name "pocl")
- (version "1.4")
- (source
- (origin
- (method git-fetch)
- (uri (git-reference
- (url "https://github.com/pocl/pocl")
- (commit (string-append "v" version))))
- (sha256
- (base32 "1c4y69zks6hkq5fqh9waxgb8g4ka7y6h3vacmsm720kba0h57g8a"))
- (file-name (git-file-name name version))))
+ (version "3.1")
+ (source (origin
+ (method git-fetch)
+ (uri (git-reference
+ (url "https://github.com/pocl/pocl")
+ (commit (string-append "v" version))))
+ (sha256
+ (base32
+ "1pw4q0hi5ynx34fvzryravz3jbh89f9cg60fkjj77sxh9xw8phdd"))
+ (file-name (git-file-name name version))))
(build-system cmake-build-system)
- (native-inputs
- (list libltdl pkg-config))
- (inputs
- (list clang-9 llvm-9 `(,hwloc-2 "lib") opencl-icd-loader))
+ (native-inputs (list libltdl pkg-config python-3))
+ (inputs (list clang-15 llvm-15
+ `(,hwloc-2 "lib") opencl-icd-loader))
(arguments
- `(#:configure-flags
- (list "-DENABLE_ICD=ON"
- "-DENABLE_TESTSUITES=ON"
- ;; We are not developers, don't run conformance suite.
- "-DENABLE_CONFORMANCE=OFF"
- (string-append "-DEXTRA_HOST_LD_FLAGS=-L"
- (assoc-ref %build-inputs "libc") "/lib"))
- #:phases
- (modify-phases %standard-phases
- (add-before 'check 'set-HOME
- (lambda _
- (setenv "HOME" "/tmp")
+ `(#:configure-flags (let* ((libdir (string-append (assoc-ref %outputs
+ "out")
+ "/lib")))
+ (list "-DENABLE_ICD=ON"
+ "-DENABLE_TESTSUITES=ON"
+ ;; We are not developers, don't run conformance suite.
+ "-DENABLE_CONFORMANCE=OFF"
+ (string-append "-DEXTRA_HOST_LD_FLAGS=-L"
+ (assoc-ref %build-inputs
+ "libc") "/lib")
+ ;; We need both libdir and libdir/pocl in RUNPATH.
+ (string-append "-DCMAKE_INSTALL_RPATH="
+ libdir ";" libdir "/pocl")))
+ #:phases (modify-phases %standard-phases
+ (add-after 'unpack 'make-failed-tests-on-aarch64-expected-for-cmake
+ (lambda _
+ (substitute* "tests/kernel/CMakeLists.txt"
+ ;; "kernel/test_printf_vectors" and "kernel/test_printf_vectors_ulongn"
+ ;; also fail on aarch54, so let them be marked "WILL_DAIL" as well in CMakeLists.txt
+ (("aarch64-linux-gnu") ""))))
+ (add-before 'check 'set-HOME
+ (lambda _
+ (setenv "HOME" "/tmp")
- ;; Since 2.9.0, hwloc fails when /sys is missing, so provide a
- ;; fake topology.
- (setenv "HWLOC_SYNTHETIC" "4"))))))
+ ;; Since 2.9.0, hwloc fails when /sys is missing, so provide a
+ ;; fake topology.
+ (setenv "HWLOC_SYNTHETIC" "4"))))))
(home-page "http://portablecl.org/")
(synopsis "Portable Computing Language (pocl), an OpenCL implementation")
(description

base-commit: 7001cc68b6d5785a8dd6aa202d4acbb2ea9364e5
--
2.39.1
Andy Tai wrote 2 years ago
[PATCH v3] gnu: pocl: Update to 3.1
(address . 62070@debbugs.gnu.org)(name . Andy Tai)(address . atai@atai.org)
20230312093708.11986-1-atai@atai.org
* gnu/packages/opencl.scm (pocl): Update to 3.1
[native-inputs]: Add python-3
[arguments]: Update RPATH. Handle failed tests on aarch64
---
gnu/packages/opencl.scm | 71 ++++++++++++++++++++++++-----------------
1 file changed, 42 insertions(+), 29 deletions(-)

Toggle diff (89 lines)
diff --git a/gnu/packages/opencl.scm b/gnu/packages/opencl.scm
index 2e506156b2..703746c1d0 100644
--- a/gnu/packages/opencl.scm
+++ b/gnu/packages/opencl.scm
@@ -279,38 +279,51 @@ (define-public beignet
(define-public pocl
(package
(name "pocl")
- (version "1.4")
- (source
- (origin
- (method git-fetch)
- (uri (git-reference
- (url "https://github.com/pocl/pocl")
- (commit (string-append "v" version))))
- (sha256
- (base32 "1c4y69zks6hkq5fqh9waxgb8g4ka7y6h3vacmsm720kba0h57g8a"))
- (file-name (git-file-name name version))))
+ (version "3.1")
+ (source (origin
+ (method git-fetch)
+ (uri (git-reference
+ (url "https://github.com/pocl/pocl")
+ (commit (string-append "v" version))))
+ (sha256
+ (base32
+ "1pw4q0hi5ynx34fvzryravz3jbh89f9cg60fkjj77sxh9xw8phdd"))
+ (file-name (git-file-name name version))))
(build-system cmake-build-system)
- (native-inputs
- (list libltdl pkg-config))
- (inputs
- (list clang-9 llvm-9 `(,hwloc-2 "lib") opencl-icd-loader))
+ (native-inputs (list libltdl pkg-config python-3))
+ (inputs (list clang-15 llvm-15
+ `(,hwloc-2 "lib") opencl-icd-loader))
(arguments
- `(#:configure-flags
- (list "-DENABLE_ICD=ON"
- "-DENABLE_TESTSUITES=ON"
- ;; We are not developers, don't run conformance suite.
- "-DENABLE_CONFORMANCE=OFF"
- (string-append "-DEXTRA_HOST_LD_FLAGS=-L"
- (assoc-ref %build-inputs "libc") "/lib"))
- #:phases
- (modify-phases %standard-phases
- (add-before 'check 'set-HOME
- (lambda _
- (setenv "HOME" "/tmp")
+ `(#:configure-flags (let* ((libdir (string-append (assoc-ref %outputs
+ "out")
+ "/lib")))
+ (list "-DENABLE_ICD=ON"
+ "-DENABLE_TESTSUITES=ON"
+ ;; We are not developers, don't run conformance suite.
+ "-DENABLE_CONFORMANCE=OFF"
+ (string-append "-DEXTRA_HOST_LD_FLAGS=-L"
+ (assoc-ref %build-inputs
+ "libc") "/lib")
+ ;; We need both libdir and libdir/pocl in RUNPATH.
+ (string-append "-DCMAKE_INSTALL_RPATH="
+ libdir ";" libdir "/pocl")))
+ #:phases (modify-phases %standard-phases
+ (add-after 'unpack 'make-failed-tests-on-aarch64-expected-for-cmake
+ (lambda _
+ (substitute* "tests/kernel/CMakeLists.txt"
+ ;; "kernel/test_printf_vectors" and
+ ;; "kernel/test_printf_vectors_ulongn"
+ ;; also fail on aarch54, so let them be marked
+ ;; "WILL_FAIL" as well in CMakeLists.txt
+ (("aarch64-linux-gnu")
+ ""))))
+ (add-before 'check 'set-HOME
+ (lambda _
+ (setenv "HOME" "/tmp")
- ;; Since 2.9.0, hwloc fails when /sys is missing, so provide a
- ;; fake topology.
- (setenv "HWLOC_SYNTHETIC" "4"))))))
+ ;; Since 2.9.0, hwloc fails when /sys is missing, so provide a
+ ;; fake topology.
+ (setenv "HWLOC_SYNTHETIC" "4"))))))
(home-page "http://portablecl.org/")
(synopsis "Portable Computing Language (pocl), an OpenCL implementation")
(description

base-commit: 7001cc68b6d5785a8dd6aa202d4acbb2ea9364e5
diff --git a/gnu/packages/opencl.scm b/gnu/packages/opencl.scm
index 2e506156b2..01c1d40d6c 100644
--- a/gnu/packages/opencl.scm
+++ b/gnu/packages/opencl.scm
@@ -279,38 +279,42 @@ (define-public beignet
(define-public pocl
(package
(name "pocl")
- (version "1.4")
- (source
- (origin
- (method git-fetch)
- (uri (git-reference
- (url "https://github.com/pocl/pocl")
- (commit (string-append "v" version))))
- (sha256
- (base32 "1c4y69zks6hkq5fqh9waxgb8g4ka7y6h3vacmsm720kba0h57g8a"))
- (file-name (git-file-name name version))))
+ (version "3.1")
+ (source (origin
+ (method git-fetch)
+ (uri (git-reference
+ (url "https://github.com/pocl/pocl")
+ (commit (string-append "v" version))))
+ (sha256
+ (base32
+ "1pw4q0hi5ynx34fvzryravz3jbh89f9cg60fkjj77sxh9xw8phdd"))
+ (file-name (git-file-name name version))))
(build-system cmake-build-system)
- (native-inputs
- (list libltdl pkg-config))
- (inputs
- (list clang-9 llvm-9 `(,hwloc-2 "lib") opencl-icd-loader))
+ (native-inputs (list libltdl pkg-config python-3))
+ (inputs (list clang-9 llvm-9
+ `(,hwloc-2 "lib") opencl-icd-loader))
(arguments
- `(#:configure-flags
- (list "-DENABLE_ICD=ON"
- "-DENABLE_TESTSUITES=ON"
- ;; We are not developers, don't run conformance suite.
- "-DENABLE_CONFORMANCE=OFF"
- (string-append "-DEXTRA_HOST_LD_FLAGS=-L"
- (assoc-ref %build-inputs "libc") "/lib"))
- #:phases
- (modify-phases %standard-phases
- (add-before 'check 'set-HOME
- (lambda _
- (setenv "HOME" "/tmp")
+ `(#:configure-flags (let* ((libdir (string-append (assoc-ref %outputs
+ "out")
+ "/lib")))
+ (list "-DENABLE_ICD=ON"
+ "-DENABLE_TESTSUITES=ON"
+ ;; We are not developers, don't run conformance suite.
+ "-DENABLE_CONFORMANCE=OFF"
+ (string-append "-DEXTRA_HOST_LD_FLAGS=-L"
+ (assoc-ref %build-inputs
+ "libc") "/lib")
+ ;; We need both libdir and libdir/pocl in RUNPATH.
+ (string-append "-DCMAKE_INSTALL_RPATH="
+ libdir ";" libdir "/pocl")))
+ #:phases (modify-phases %standard-phases
+ (add-before 'check 'set-HOME
+ (lambda _
+ (setenv "HOME" "/tmp")
- ;; Since 2.9.0, hwloc fails when /sys is missing, so provide a
- ;; fake topology.
- (setenv "HWLOC_SYNTHETIC" "4"))))))
+ ;; Since 2.9.0, hwloc fails when /sys is missing, so provide a
+ ;; fake topology.
+ (setenv "HWLOC_SYNTHETIC" "4"))))))
(home-page "http://portablecl.org/")
(synopsis "Portable Computing Language (pocl), an OpenCL implementation")
(description

base-commit: f289fe316aaa06e60f4b10e75e113cf1aeb03629
--
2.39.1
Andy Tai wrote 2 years ago
(address . 62070@debbugs.gnu.org)(name . Andy Tai)(address . atai@atai.org)
20230310004715.11762-1-atai@atai.org
* gnu/packages/opencl.scm (pocl): Update to 3.1
[native-inputs]: Add python-3
[arguments]: Update RPATH
---
gnu/packages/opencl.scm | 62 ++++++++++++++++++++++-------------------
1 file changed, 33 insertions(+), 29 deletions(-)

Toggle diff (80 lines)
diff --git a/gnu/packages/opencl.scm b/gnu/packages/opencl.scm
index 2e506156b2..b25438ba98 100644
--- a/gnu/packages/opencl.scm
+++ b/gnu/packages/opencl.scm
@@ -279,38 +279,42 @@ (define-public beignet
(define-public pocl
(package
(name "pocl")
- (version "1.4")
- (source
- (origin
- (method git-fetch)
- (uri (git-reference
- (url "https://github.com/pocl/pocl")
- (commit (string-append "v" version))))
- (sha256
- (base32 "1c4y69zks6hkq5fqh9waxgb8g4ka7y6h3vacmsm720kba0h57g8a"))
- (file-name (git-file-name name version))))
+ (version "3.1")
+ (source (origin
+ (method git-fetch)
+ (uri (git-reference
+ (url "https://github.com/pocl/pocl")
+ (commit (string-append "v" version))))
+ (sha256
+ (base32
+ "1pw4q0hi5ynx34fvzryravz3jbh89f9cg60fkjj77sxh9xw8phdd"))
+ (file-name (git-file-name name version))))
(build-system cmake-build-system)
- (native-inputs
- (list libltdl pkg-config))
- (inputs
- (list clang-9 llvm-9 `(,hwloc-2 "lib") opencl-icd-loader))
+ (native-inputs (list libltdl pkg-config python-3))
+ (inputs (list clang-15 llvm-15
+ `(,hwloc-2 "lib") opencl-icd-loader))
(arguments
- `(#:configure-flags
- (list "-DENABLE_ICD=ON"
- "-DENABLE_TESTSUITES=ON"
- ;; We are not developers, don't run conformance suite.
- "-DENABLE_CONFORMANCE=OFF"
- (string-append "-DEXTRA_HOST_LD_FLAGS=-L"
- (assoc-ref %build-inputs "libc") "/lib"))
- #:phases
- (modify-phases %standard-phases
- (add-before 'check 'set-HOME
- (lambda _
- (setenv "HOME" "/tmp")
+ `(#:configure-flags (let* ((libdir (string-append (assoc-ref %outputs
+ "out")
+ "/lib")))
+ (list "-DENABLE_ICD=ON"
+ "-DENABLE_TESTSUITES=ON"
+ ;; We are not developers, don't run conformance suite.
+ "-DENABLE_CONFORMANCE=OFF"
+ (string-append "-DEXTRA_HOST_LD_FLAGS=-L"
+ (assoc-ref %build-inputs
+ "libc") "/lib")
+ ;; We need both libdir and libdir/pocl in RUNPATH.
+ (string-append "-DCMAKE_INSTALL_RPATH="
+ libdir ";" libdir "/pocl")))
+ #:phases (modify-phases %standard-phases
+ (add-before 'check 'set-HOME
+ (lambda _
+ (setenv "HOME" "/tmp")
- ;; Since 2.9.0, hwloc fails when /sys is missing, so provide a
- ;; fake topology.
- (setenv "HWLOC_SYNTHETIC" "4"))))))
+ ;; Since 2.9.0, hwloc fails when /sys is missing, so provide a
+ ;; fake topology.
+ (setenv "HWLOC_SYNTHETIC" "4"))))))
(home-page "http://portablecl.org/")
(synopsis "Portable Computing Language (pocl), an OpenCL implementation")
(description

base-commit: f289fe316aaa06e60f4b10e75e113cf1aeb03629
--
2.39.1
Andy Tai wrote 2 years ago
(address . 62070@debbugs.gnu.org)(name . Andy Tai)(address . atai@atai.org)
20230313055520.6366-1-atai@atai.org
* gnu/packages/opencl.scm (pocl): Update to 3.1
[native-inputs]: Add python-3
[arguments]: Update RPATH. Skip failed tests on aarch64
---
gnu/packages/opencl.scm | 71 ++++++++++++++++++++++++-----------------
1 file changed, 42 insertions(+), 29 deletions(-)

Toggle diff (89 lines)
diff --git a/gnu/packages/opencl.scm b/gnu/packages/opencl.scm
index 2e506156b2..a2332aa34f 100644
--- a/gnu/packages/opencl.scm
+++ b/gnu/packages/opencl.scm
@@ -279,38 +279,51 @@ (define-public beignet
(define-public pocl
(package
(name "pocl")
- (version "1.4")
- (source
- (origin
- (method git-fetch)
- (uri (git-reference
- (url "https://github.com/pocl/pocl")
- (commit (string-append "v" version))))
- (sha256
- (base32 "1c4y69zks6hkq5fqh9waxgb8g4ka7y6h3vacmsm720kba0h57g8a"))
- (file-name (git-file-name name version))))
+ (version "3.1")
+ (source (origin
+ (method git-fetch)
+ (uri (git-reference
+ (url "https://github.com/pocl/pocl")
+ (commit (string-append "v" version))))
+ (sha256
+ (base32
+ "1pw4q0hi5ynx34fvzryravz3jbh89f9cg60fkjj77sxh9xw8phdd"))
+ (file-name (git-file-name name version))))
(build-system cmake-build-system)
- (native-inputs
- (list libltdl pkg-config))
- (inputs
- (list clang-9 llvm-9 `(,hwloc-2 "lib") opencl-icd-loader))
+ (native-inputs (list libltdl pkg-config python-3))
+ (inputs (list clang-15 llvm-15
+ `(,hwloc-2 "lib") opencl-icd-loader))
(arguments
- `(#:configure-flags
- (list "-DENABLE_ICD=ON"
- "-DENABLE_TESTSUITES=ON"
- ;; We are not developers, don't run conformance suite.
- "-DENABLE_CONFORMANCE=OFF"
- (string-append "-DEXTRA_HOST_LD_FLAGS=-L"
- (assoc-ref %build-inputs "libc") "/lib"))
- #:phases
- (modify-phases %standard-phases
- (add-before 'check 'set-HOME
- (lambda _
- (setenv "HOME" "/tmp")
+ `(#:configure-flags (let* ((libdir (string-append (assoc-ref %outputs
+ "out")
+ "/lib")))
+ (list "-DENABLE_ICD=ON"
+ "-DENABLE_TESTSUITES=ON"
+ ;; We are not developers, don't run conformance suite.
+ "-DENABLE_CONFORMANCE=OFF"
+ (string-append "-DEXTRA_HOST_LD_FLAGS=-L"
+ (assoc-ref %build-inputs
+ "libc") "/lib")
+ ;; We need both libdir and libdir/pocl in RUNPATH.
+ (string-append "-DCMAKE_INSTALL_RPATH="
+ libdir ";" libdir "/pocl")))
+ #:phases (modify-phases %standard-phases
+ (add-after 'check 'skip-failed-tests-on-aarch64
+ (lambda _
+ (call-with-output-file "CTestCustom.cmake"
+ (lambda (port)
+ (display (string-append
+ "set(CTEST_CUSTOM_TESTS_IGNORE "
+ "test_printf_vectors"
+ "test_printf_vectors_ulongn" ")\n") port)))))
+
+ (add-before 'check 'set-HOME
+ (lambda _
+ (setenv "HOME" "/tmp")
- ;; Since 2.9.0, hwloc fails when /sys is missing, so provide a
- ;; fake topology.
- (setenv "HWLOC_SYNTHETIC" "4"))))))
+ ;; Since 2.9.0, hwloc fails when /sys is missing, so provide a
+ ;; fake topology.
+ (setenv "HWLOC_SYNTHETIC" "4"))))))
(home-page "http://portablecl.org/")
(synopsis "Portable Computing Language (pocl), an OpenCL implementation")
(description

base-commit: 7001cc68b6d5785a8dd6aa202d4acbb2ea9364e5
--
2.39.1
Andy Tai wrote 2 years ago
[PATCH v4] gnu: pocl: Update to 3.1
(address . 62070@debbugs.gnu.org)(name . Andy Tai)(address . atai@atai.org)
20230313064949.7780-1-atai@atai.org
* gnu/packages/opencl.scm (pocl): Update to 3.1
[native-inputs]: Add python-3
[arguments]: Update RPATH. Skip failed tests on aarch64
---
gnu/packages/opencl.scm | 71 ++++++++++++++++++++++++-----------------
1 file changed, 42 insertions(+), 29 deletions(-)

Toggle diff (89 lines)
diff --git a/gnu/packages/opencl.scm b/gnu/packages/opencl.scm
index 2e506156b2..a2332aa34f 100644
--- a/gnu/packages/opencl.scm
+++ b/gnu/packages/opencl.scm
@@ -279,38 +279,51 @@ (define-public beignet
(define-public pocl
(package
(name "pocl")
- (version "1.4")
- (source
- (origin
- (method git-fetch)
- (uri (git-reference
- (url "https://github.com/pocl/pocl")
- (commit (string-append "v" version))))
- (sha256
- (base32 "1c4y69zks6hkq5fqh9waxgb8g4ka7y6h3vacmsm720kba0h57g8a"))
- (file-name (git-file-name name version))))
+ (version "3.1")
+ (source (origin
+ (method git-fetch)
+ (uri (git-reference
+ (url "https://github.com/pocl/pocl")
+ (commit (string-append "v" version))))
+ (sha256
+ (base32
+ "1pw4q0hi5ynx34fvzryravz3jbh89f9cg60fkjj77sxh9xw8phdd"))
+ (file-name (git-file-name name version))))
(build-system cmake-build-system)
- (native-inputs
- (list libltdl pkg-config))
- (inputs
- (list clang-9 llvm-9 `(,hwloc-2 "lib") opencl-icd-loader))
+ (native-inputs (list libltdl pkg-config python-3))
+ (inputs (list clang-15 llvm-15
+ `(,hwloc-2 "lib") opencl-icd-loader))
(arguments
- `(#:configure-flags
- (list "-DENABLE_ICD=ON"
- "-DENABLE_TESTSUITES=ON"
- ;; We are not developers, don't run conformance suite.
- "-DENABLE_CONFORMANCE=OFF"
- (string-append "-DEXTRA_HOST_LD_FLAGS=-L"
- (assoc-ref %build-inputs "libc") "/lib"))
- #:phases
- (modify-phases %standard-phases
- (add-before 'check 'set-HOME
- (lambda _
- (setenv "HOME" "/tmp")
+ `(#:configure-flags (let* ((libdir (string-append (assoc-ref %outputs
+ "out")
+ "/lib")))
+ (list "-DENABLE_ICD=ON"
+ "-DENABLE_TESTSUITES=ON"
+ ;; We are not developers, don't run conformance suite.
+ "-DENABLE_CONFORMANCE=OFF"
+ (string-append "-DEXTRA_HOST_LD_FLAGS=-L"
+ (assoc-ref %build-inputs
+ "libc") "/lib")
+ ;; We need both libdir and libdir/pocl in RUNPATH.
+ (string-append "-DCMAKE_INSTALL_RPATH="
+ libdir ";" libdir "/pocl")))
+ #:phases (modify-phases %standard-phases
+ (add-after 'check 'skip-failed-tests-on-aarch64
+ (lambda _
+ (call-with-output-file "CTestCustom.cmake"
+ (lambda (port)
+ (display (string-append
+ "set(CTEST_CUSTOM_TESTS_IGNORE "
+ "test_printf_vectors"
+ "test_printf_vectors_ulongn" ")\n") port)))))
+
+ (add-before 'check 'set-HOME
+ (lambda _
+ (setenv "HOME" "/tmp")
- ;; Since 2.9.0, hwloc fails when /sys is missing, so provide a
- ;; fake topology.
- (setenv "HWLOC_SYNTHETIC" "4"))))))
+ ;; Since 2.9.0, hwloc fails when /sys is missing, so provide a
+ ;; fake topology.
+ (setenv "HWLOC_SYNTHETIC" "4"))))))
(home-page "http://portablecl.org/")
(synopsis "Portable Computing Language (pocl), an OpenCL implementation")
(description

base-commit: 7001cc68b6d5785a8dd6aa202d4acbb2ea9364e5
--
2.39.1
Andy Tai wrote 2 years ago
[PATCH v5] gnu: pocl: Update to 3.1
(address . 62070@debbugs.gnu.org)(name . Andy Tai)(address . atai@atai.org)
20230313173408.6781-1-atai@atai.org
* gnu/packages/opencl.scm (pocl): Update to 3.1
[native-inputs]: Add python-3
[arguments]: Update RPATH. Skip failed tests on aarch64
---
gnu/packages/opencl.scm | 73 +++++++++++++++++++++++++----------------
1 file changed, 44 insertions(+), 29 deletions(-)

Toggle diff (91 lines)
diff --git a/gnu/packages/opencl.scm b/gnu/packages/opencl.scm
index 2e506156b2..85b063b136 100644
--- a/gnu/packages/opencl.scm
+++ b/gnu/packages/opencl.scm
@@ -279,38 +279,53 @@ (define-public beignet
(define-public pocl
(package
(name "pocl")
- (version "1.4")
- (source
- (origin
- (method git-fetch)
- (uri (git-reference
- (url "https://github.com/pocl/pocl")
- (commit (string-append "v" version))))
- (sha256
- (base32 "1c4y69zks6hkq5fqh9waxgb8g4ka7y6h3vacmsm720kba0h57g8a"))
- (file-name (git-file-name name version))))
+ (version "3.1")
+ (source (origin
+ (method git-fetch)
+ (uri (git-reference
+ (url "https://github.com/pocl/pocl")
+ (commit (string-append "v" version))))
+ (sha256
+ (base32
+ "1pw4q0hi5ynx34fvzryravz3jbh89f9cg60fkjj77sxh9xw8phdd"))
+ (file-name (git-file-name name version))
+ (modules '((guix build utils)))
+ (snippet
+ '(begin
+ ;; "kernel/test_printf_vectors" and
+ ;; "kernel/test_printf_vectors_ulongn"
+ ;; fail on aarch5 and likely other platforms
+ ;; as commented in CMakeLists.txt
+ ;; thus disable the block in CMakeList.txt adding
+ ;; these two tests
+ (substitute* "tests/kernel/CMakeLists.txt"
+ (("NOT ENABLE_POCL_FLOAT_CONVERSION") "false"))))))
(build-system cmake-build-system)
- (native-inputs
- (list libltdl pkg-config))
- (inputs
- (list clang-9 llvm-9 `(,hwloc-2 "lib") opencl-icd-loader))
+ (native-inputs (list libltdl pkg-config python-3))
+ (inputs (list clang-15 llvm-15
+ `(,hwloc-2 "lib") opencl-icd-loader))
(arguments
- `(#:configure-flags
- (list "-DENABLE_ICD=ON"
- "-DENABLE_TESTSUITES=ON"
- ;; We are not developers, don't run conformance suite.
- "-DENABLE_CONFORMANCE=OFF"
- (string-append "-DEXTRA_HOST_LD_FLAGS=-L"
- (assoc-ref %build-inputs "libc") "/lib"))
- #:phases
- (modify-phases %standard-phases
- (add-before 'check 'set-HOME
- (lambda _
- (setenv "HOME" "/tmp")
+ `(#:configure-flags (let* ((libdir (string-append (assoc-ref %outputs
+ "out")
+ "/lib")))
+ (list "-DENABLE_ICD=ON"
+ "-DENABLE_TESTSUITES=ON"
+ ;; We are not developers, don't run conformance suite.
+ "-DENABLE_CONFORMANCE=OFF"
+ (string-append "-DEXTRA_HOST_LD_FLAGS=-L"
+ (assoc-ref %build-inputs
+ "libc") "/lib")
+ ;; We need both libdir and libdir/pocl in RUNPATH.
+ (string-append "-DCMAKE_INSTALL_RPATH="
+ libdir ";" libdir "/pocl")))
+ #:phases (modify-phases %standard-phases
+ (add-before 'check 'set-HOME
+ (lambda _
+ (setenv "HOME" "/tmp")
- ;; Since 2.9.0, hwloc fails when /sys is missing, so provide a
- ;; fake topology.
- (setenv "HWLOC_SYNTHETIC" "4"))))))
+ ;; Since 2.9.0, hwloc fails when /sys is missing, so provide a
+ ;; fake topology.
+ (setenv "HWLOC_SYNTHETIC" "4"))))))
(home-page "http://portablecl.org/")
(synopsis "Portable Computing Language (pocl), an OpenCL implementation")
(description

base-commit: 7001cc68b6d5785a8dd6aa202d4acbb2ea9364e5
--
2.39.1
Ludovic Courtès wrote 2 years ago
Re: bug#62070: [PATCH] gnu: pocl: Update to 3.1
(name . Andy Tai)(address . atai@atai.org)(address . 62070-done@debbugs.gnu.org)
87edpidlnp.fsf_-_@gnu.org
Hi Andy,

Andy Tai <atai@atai.org> skribis:

Toggle quote (4 lines)
> * gnu/packages/opencl.scm (pocl): Update to 3.1
> [native-inputs]: Add python-3
> [arguments]: Update RPATH. Skip failed tests on aarch64

Applied, thanks!

Ludo’.
Closed
Andy Tai wrote 2 years ago
(name . Ludovic Courtès)(address . ludo@gnu.org)(address . 62070-done@debbugs.gnu.org)
CAJsg1E_BB3AGVEW-O0k1fYEhYQh8cd2LZVQW1--2gUWFt7LBOQ@mail.gmail.com
Thanks!

On Tue, Mar 21, 2023 at 11:06 AM Ludovic Courtès <ludo@gnu.org> wrote:

Toggle quote (14 lines)
> Hi Andy,
>
> Andy Tai <atai@atai.org> skribis:
>
> > * gnu/packages/opencl.scm (pocl): Update to 3.1
> > [native-inputs]: Add python-3
> > [arguments]: Update RPATH. Skip failed tests on aarch64
>
> Applied, thanks!
>
> Ludo’.
>


--
Andy Tai, atai@atai.org, Skype: licheng.tai, Line: andy_tai, WeChat:
andytai1010
Year 2023 民國112年
自動的精神力是信仰與覺悟
自動的行為力是勞動與技能
Attachment: file
Closed
?
Your comment

This issue is archived.

To comment on this conversation send an email to 62070@debbugs.gnu.org

To respond to this issue using the mumi CLI, first switch to it
mumi current 62070
Then, you may apply the latest patchset in this issue (with sign off)
mumi am -- -s
Or, compose a reply to this issue
mumi compose
Or, send patches to this issue
mumi send-email *.patch
You may also tag this issue. See list of standard tags. For example, to set the confirmed and easy tags
mumi command -t +confirmed -t +easy
Or, remove the moreinfo tag and set the help tag
mumi command -t -moreinfo -t +help